@@ -1,10 +1,11 @@
 //------------------------------------------------------------------------------
 // Project:  arrayfunc
 // Module:   aany_simd_x86.c
-// Purpose:  Returns True if any element in an array meets the selected criteria.
+// Purpose:  Returns True if any elements in an array meet the selected criteria.
 //           This file provides an SIMD version of the functions.
 // Language: C
-// Date:     03-May-2017
+// Date:     01-May-2017
+// Ver:      24-Sep-2017.
 //
 //------------------------------------------------------------------------------
 //
@@ -33,7 +34,6 @@
 
 #include "arrayfunc.h"
 #include "arrayerrs.h"
-#include "simddefs.h"
 
 /*--------------------------------------------------------------------------- */
 
@@ -41,7 +41,6 @@
 
 // Auto generated code goes below.
 
-
 /*--------------------------------------------------------------------------- */
 /* For array code: b
    opcode = The operator or function code to select what to execute.
