@@ -4,7 +4,8 @@
 // Purpose:  Find the maximum value in an array.
 //           This file provides an SIMD version of the functions.
 // Language: C
-// Date:     04-May-2017
+// Date:     01-May-2017
+// Ver:      24-Sep-2017.
 //
 //------------------------------------------------------------------------------
 //
@@ -33,7 +34,6 @@
 
 #include "arrayfunc.h"
 #include "arrayerrs.h"
-#include "simddefs.h"
 
 /*--------------------------------------------------------------------------- */
 
@@ -41,7 +41,6 @@
 
 // Auto generated code goes below.
 
-
 /*--------------------------------------------------------------------------- */
 /* For array code: b
    arraylen = The length of the data arrays.
